"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
exports.resolveTsconfigFilePath = exports.loadTsconfig = exports.loadAliasConfigs = void 0;
var find_up_1 = require("find-up");
var micromatch_1 = __importDefault(require("micromatch"));
var path_1 = require("path");
var tsconfig_paths_1 = require("tsconfig-paths");
function resolveTsconfigFilePath(startDirs, aliasConfigPath) {
    var configFilePath = startDirs
        .map(function (dir) {
        return (0, find_up_1.sync)([aliasConfigPath, "tsconfig.json", "jsconfig.json"].filter(Boolean), { cwd: dir });
    })
        .find(function (tsconfigPath) { return !!tsconfigPath; });
    if (!configFilePath) {
        throw new Error("cannot find TSConfig or JSConfig, try assigning aliasConfigPath");
    }
    return configFilePath;
}
exports.resolveTsconfigFilePath = resolveTsconfigFilePath;
function loadTsconfig(configFilePath) {
    var config;
    try {
        config = (0, tsconfig_paths_1.loadConfig)(configFilePath);
    }
    catch (error) {
        if (error instanceof SyntaxError) {
            throw new Error("SyntaxError in TSConfig/JSConfig: ".concat(error.message));
        }
        throw error;
    }
    if (config.resultType !== "success") {
        throw new Error("validate tsconfig or jsconfig provided and ensure compilerOptions.baseUrl is set: ".concat(config.message));
    }
    return config;
}
exports.loadTsconfig = loadTsconfig;
function loadAliasConfigs(config, projectBaseDir) {
    return Object.entries(config.paths).reduce(function (configs, _a) {
        var aliasGlob = _a[0], aliasPaths = _a[1];
        aliasPaths.forEach(function (aliasPath) {
            var relativePathBase = micromatch_1["default"].scan(aliasPath).base;
            configs.push({
                alias: micromatch_1["default"].scan(aliasGlob).base,
                path: {
                    absolute: (0, path_1.join)(projectBaseDir, relativePathBase)
                }
            });
        });
        return configs;
    }, []);
}
exports.loadAliasConfigs = loadAliasConfigs;
